pub struct BlockFetchBehavior { /* private fields */ }Expand description
Sub-behavior that manages block fetching from peers.
Implementations
Sourceimpl BlockFetchBehavior
impl BlockFetchBehavior
Sourcepub fn new(_config: ()) -> BlockFetchBehavior
pub fn new(_config: ()) -> BlockFetchBehavior
Creates a new block-fetch behavior with the given configuration.
Sourcepub fn enqueue(&mut self, request: (Point, Point))
pub fn enqueue(&mut self, request: (Point, Point))
Adds a block range request to the pending queue.
Sourcepub fn request_block_batch(
&self,
pid: &PeerId,
range: (Point, Point),
outbound: &mut OutboundQueue<InitiatorBehavior>,
)
pub fn request_block_batch( &self, pid: &PeerId, range: (Point, Point), outbound: &mut OutboundQueue<InitiatorBehavior>, )
Sends a block range request to the specified peer.
Sourcepub fn dispatch_block(
&self,
pid: &PeerId,
state: &InitiatorState,
outbound: &mut OutboundQueue<InitiatorBehavior>,
)
pub fn dispatch_block( &self, pid: &PeerId, state: &InitiatorState, outbound: &mut OutboundQueue<InitiatorBehavior>, )
Emits a BlockBodyReceived
event if the peer’s block-fetch state contains a new block.